<?xml version="1.0" encoding="UTF-8"?>

<#-- Attachments list main template file -->

<#-- Include utilities for the list of attachment identifiers -->
<#include "attachments_mixtures_bpr_utilities.ftl" />

<#-- Import common macros and functions -->
<#import "macros_common.ftl" as com>

<!-- Attachments -->
<#assign locale = "en" />
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

<#assign substance = rootDocument />
<#assign mixture = rootDocument />
	
    <info>
        <title>Attachments for a biocidal product/mixture dossier</title>
		<cover>
				<para>
				<@com.emptyLine/>
				
				The report herein provides a list of attachments contained in the mixture/product: 
				<emphasis role="bold"><@com.text mixture.MixtureName /></emphasis>
				<#if mixture.PublicName?has_content> (public name: <@com.text mixture.PublicName />)</#if>
								
				<itemizedlist mark='bullet'>
					The report is split into three tables. 
					<listitem>
						The <emphasis>first</emphasis> table lists the attachments belonging to a biocidal product dataset or dossier.
					</listitem>
					<@com.emptyLine/>
					<listitem>
						The <emphasis>second</emphasis> table lists the attachments belonging to active substance(s) or mixture(s) which have been linked to the Composition section 2.3 of the biocidal product.
					</listitem>
					<@com.emptyLine/>
					<listitem>
						The <emphasis>third</emphasis> table lists the attachments belonging to substance(s) or mixture(s), other than an active substance, which have been linked to the Composition section 2.3 of the biocidal product.
					</listitem>							
				</itemizedlist>
				
				<@com.emptyLine/>
				The ordering of the attachments is based on the <emphasis>type</emphasis> of attachment. 
				<@com.emptyLine/>
				For example, the attachments found in the 'Information panel' of IUCLID are populated first.
				</para>
        </cover>
    </info>
	
	<chapter label="1">	
	<title role="HEAD-1">Attachments for a biocidal product/mixture</title>		
		<!-- Attachments (mixture/product) -->
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Attachments in the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<!-- Biocidal Product attachments in metadata -->							
					<#-- Biocidal Product attachments in metadata -->						
					<#list mixtureAttachmentMetaDataListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
							<#list document.attachments as attachments>	
							<@tableRowForAttachments document attachments attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
							</#list>
						</#list>
					</#list>
					<#assign document = mixture />
					<#if document?has_content>
						<#list document.attachments as attachments>
						<@tableRowForAttachments document attachments mixtureAttachmentMetaDataListPart2 "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
						</#list>
					</#if>	
					<#list mixtureAttachmentMetaDataListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
							<#list document.attachments as attachments>	
							<@tableRowForAttachments document attachments attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
							</#list>
						</#list>
					</#list>
					
					<!-- Biocidal Product attachments in documents -->
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
					<#list documentList as document>
						<#if isAssignmentSupplierAttachment(document, mixtureSuppliersAssignmentID)>
						<@tableRowForAssignedSuppliers document mixtureSuppliersAssignmentID "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
						</#if>
					</#list>
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
					<#list documentList as document>
						<#list document.OnlyRepresentationInfo.ImporterEntries as otherImportersItem>
							<#if otherImportersItem?has_content>
							<@tableRowForSuppliersOtherImporters otherImportersItem mixtureSuppliersAgreementID "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
							</#if>
						</#list>
					</#list>						
					<#list mixtureImageList as attachmentIdentifier>
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
							<#if document?has_content>
								<#if isImageAttachmentPresent(document, attachmentIdentifier)>
								<@tableRowForImages document attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
								</#if>
							</#if>
						</#list>
					</#list>
					<#list mixtureBackgroundMaterialList as attachmentIdentifier>
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>	
							<#if document?has_content>
							<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
								<#if backgroundJustificationItem?has_content>
								<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />			
								</#if>
							</#list>
							</#if>
						</#list>
					</#list>
					<#list mixtureAttachedFullStudyReportList as attachmentIdentifier>	
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>	
							<#if document?has_content>
								<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
								<@tableRowForAttachedStudy document attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
								</#if>
							</#if>
						</#list>
					</#list>
					<#list mixtureJustificationForDataWaivingList as attachmentIdentifier>	
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
							<#if document?has_content>
							<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
								<#if attachedJustificationItem?has_content>
								<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
								</#if>
							</#list>
							</#if>
						</#list>
					</#list>
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "BioPackaging") />					
					<#list documentList as document>
						<#if document?has_content>
						<#list document.Packaging.PackagingRelatedAttachments as packagingRelatedAttachmentItem>
							<#if packagingRelatedAttachmentItem?has_content>
								<@tableRowForBioPackaging packagingRelatedAttachmentItem attachmentPackagingID "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
							</#if>
						</#list>
						</#if>
					</#list>
					<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_SUMMARY", "BioSummaryEvaluation") />					
					<#list documentList as document>
						<#list document.ReportsAndAdministrativeInformation.SummaryAndEvaluation.PackagingRelatedAttachments as summaryEvaluationAttachmentItem>
						<#if summaryEvaluationAttachmentItem?has_content>
							<@tableRowForSummaryEvaluationAttachment summaryEvaluationAttachmentItem summaryAndEvaluationID "Biocidal Product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
						</#if>
						</#list>
					</#list>					
				
				</tbody>					
			</table>
		</#if>	
		<#assign substance = [] />
		<#assign mixtureList = [] />
		<#assign document = [] />		
	</chapter>
	
	<chapter label="2">	
		<title role="HEAD-1">Attachments for an active substance linked to a biocidal product</title>			
		<!-- Attachments (substance) -->
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Information panel attachments in the linked active substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign activeSubstanceList = getActiveSubstanceList(mixture) />
					
					<#list activeSubstanceList as substance>	
					
						<!-- Active substance attachments in metadata -->							
						<#list substanceMetaDataAttachmentListPart1 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>								
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#list>								
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart2 as attachmentIdentifier>
						<#assign document = substance />						
							<#list document.attachments as attachments>	
							<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
							</#list>
						</#list>							
						<#list substanceMetaDataAttachmentListPart3 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart4 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						<#list substanceMetaDataAttachmentListPart5 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart6 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart7 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart8 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart9 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>							
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart10 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>						
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>						
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart11 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>								
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>								
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart12 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>					
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>							
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart13 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>							
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>						
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart14 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>							
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>								
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart15 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>							
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>				
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart16 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>							
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>				
							</#list>
						</#list>						
						<#list substanceMetaDataAttachmentListPart17 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>					
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
					</#list>	
				</tbody>					
			</table>
		</#if>	
		
		
		<!-- Attachments (substance) -->
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Document attachments in the linked active substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign activeSubstanceList = getActiveSubstanceList(mixture) />
					
					<#list activeSubstanceList as substance>	
						<#if substance?has_content>							
						
						<!-- Active substance attachments in documents -->
						<#list activeSubstanceImageListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart7 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						
						
						
						<#list activeSubstanceBackgroundMaterialListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>						
						
					
					</#if>
					</#list>
				</tbody>					
			</table>
		</#if>
				
				
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Document attachments in the linked substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign activeSubstanceList = getActiveSubstanceList(mixture) />
					
					<#list activeSubstanceList as substance>	
						<#if substance?has_content>
						
						<#list activeSubstanceAttachedFullStudyReportListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						
						
						
						
						<#list activeSubstanceJustificationForDataWaivingListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						<#list activeSubstanceJustificationForDataWaivingListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						<#list activeSubstanceJustificationForDataWaivingListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						
						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "SubstanceComposition") />					
						<#list documentList as document>
							<#list document.GeneralInformation.AttachedDescription as attachedDescriptionItem>
								<#if attachedDescriptionItem?has_content>
								<@tableRowForSubstanceComposition attachedDescriptionItem substanceCompositionID "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#if>
							</#list>
						</#list>
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "AnalyticalInformation") />					
						<#list documentList as document>
							<#list document.AnalyticalInformation.MethodsAndResultsOfAnalysis.AnalyticalDetermination as attachedAnalyticalDeterminationItem>
								<#if attachedAnalyticalDeterminationItem?has_content>
								<@tableRowForAnalyticalDetermination attachedAnalyticalDeterminationItem analyticalDeterminationID "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#if>
							</#list>
						</#list>
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
						<#list documentList as document>
							<#if document?has_content>
							<#if isAssignmentSupplierAttachment(document, mixtureSuppliersAssignmentID)>
							<@tableRowForAssignedSuppliers document mixtureSuppliersAssignmentID "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
							</#if>
							</#if>
						</#list>						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
						<#list documentList as document>
							<#list document.OnlyRepresentationInfo.ImporterEntries as attachedOtherImportersItem>
								<#if attachedOtherImportersItem?has_content>
								<@tableRowForSuppliersOtherImporters attachedOtherImportersItem mixtureSuppliersAgreementID "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#if>
							</#list>
						</#list>
						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_SUMMARY", "BioSummaryEvaluation") />					
						<#list documentList as document>
							<#if document?has_content>
								<#list document.ReportsAndAdministrativeInformation.SummaryAndEvaluation.PackagingRelatedAttachments as typeOfReportIdentifierItem>
									<#if typeOfReportIdentifierItem?has_content>							
									<@tableRowForSummaryEvaluationTypeOfReport typeOfReportIdentifierItem activeSubstanceSummaryTypeOfReportID "Active substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
									</#if>
								</#list>
							</#if>
						</#list>
						
						
					</#if>
					</#list>
				</tbody>					
			</table>
		</#if>	
		</chapter>
						
				
		<chapter label="3">	
		<title role="HEAD-1">Attachments for a substance, other than an active substance, linked to a biocidal product</title>			
		<!-- Attachments (substance) -->		
			<table border="1" orient="land">
				<title>Information panel attachments in the linked substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign otherSubstanceList = getOtherSubstanceList(mixture) />
					
					<#list otherSubstanceList as substance>	
					
						<!-- Other substance attachments in metadata -->							
						<#list substanceMetaDataAttachmentListPart1 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart2 as attachmentIdentifier>
						<#assign document = substance />						
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
						</#list>
							
						<#list substanceMetaDataAttachmentListPart3 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart4 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						<#list substanceMetaDataAttachmentListPart5 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart6 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart7 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart8 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart9 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart10 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart11 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart12 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart13 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart14 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart15 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
								</#if>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart16 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
						
						<#list substanceMetaDataAttachmentListPart17 as attachmentIdentifier>					
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.attachments as attachments>	
								<@tableRowForAttachments document attachments attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#list>
							</#list>
						</#list>
							
					</#list>	
			</tbody>					
		</table>		
		
		<!-- Attachments (substance) -->
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Document attachments in the linked substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign otherSubstanceList = getOtherSubstanceList(mixture) />
					
					<#list otherSubstanceList as substance>	
						<#if substance?has_content>				
	
						<!-- Other substance attachments in documents -->		
						<#list activeSubstanceImageListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceImageListPart7 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>	
								<#if document?has_content>
									<#if isImageAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForImages document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
										
						
						<#list activeSubstanceBackgroundMaterialListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceBackgroundMaterialListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>							
								<#list document.OverallRemarksAttachments.AttachedBackgroundMaterial as backgroundJustificationItem>
									<#if backgroundJustificationItem?has_content>
									<@tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
								</#if>
							</#list>
						</#list>						
					
				</#if>	
				</#list>
			</#if>	
			</tbody>					
		</table>		
		
		<#assign mixtureList = checkMixtureRoot(mixture) />
		<#if mixtureList?has_content>
			<table border="1" orient="land">
				<title>Document attachments in the linked substance(s) or mixture(s) from the biocidal product</title>
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<col width="25%" />
				<tbody>
					<tr>								
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Type</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Section information</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th><?dbfo bgcolor="#4169E1" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<#assign otherSubstanceList = getOtherSubstanceList(mixture) />
					
					<#list otherSubstanceList as substance>	
						<#if substance?has_content>
						
						
						<#list activeSubstanceAttachedFullStudyReportListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart4 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart5 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						<#list activeSubstanceAttachedFullStudyReportListPart6 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
						<#list documentList as document>
								<#if document?has_content>
									<#if isFullStudyAttachmentPresent(document, attachmentIdentifier)>
									<@tableRowForAttachedStudy document attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#if>
							</#list>
						</#list>
						
						
						
						
						<#list activeSubstanceJustificationForDataWaivingListPart1 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						<#list activeSubstanceJustificationForDataWaivingListPart2 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						<#list activeSubstanceJustificationForDataWaivingListPart3 as attachmentIdentifier>					
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, attachmentIdentifier.docType, attachmentIdentifier.docSubType) />
							<#list documentList as document>
								<#list document.AdministrativeData.AttachedJustification as attachedJustificationItem>
									<#if attachedJustificationItem?has_content>
									<@tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
									</#if>
								</#list>
							</#list>
						</#list>
						
						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "SubstanceComposition") />					
						<#list documentList as document>
							<#list document.GeneralInformation.AttachedDescription as attachedDescriptionItem>
								<#if attachedDescriptionItem?has_content>
								<@tableRowForSubstanceComposition attachedDescriptionItem substanceCompositionID "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#if>
							</#list>
						</#list>
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "AnalyticalInformation") />					
						<#list documentList as document>
							<#list document.AnalyticalInformation.MethodsAndResultsOfAnalysis.AnalyticalDetermination as attachedAnalyticalDeterminationItem>
								<#if attachedAnalyticalDeterminationItem?has_content>
								<@tableRowForAnalyticalDetermination attachedAnalyticalDeterminationItem analyticalDeterminationID "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
								</#if>
							</#list>
						</#list>
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
						<#list documentList as document>
							<#if document?has_content>
							<#if isAssignmentSupplierAttachment(document, mixtureSuppliersAssignmentID)>
							<@tableRowForAssignedSuppliers document mixtureSuppliersAssignmentID "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />
							</#if>
							</#if>
						</#list>						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Suppliers") />					
						<#list documentList as document>
							<#list document.OnlyRepresentationInfo.ImporterEntries as attachedOtherImportersItem>
								<#if attachedOtherImportersItem?has_content>
								<@tableRowForSuppliersOtherImporters attachedOtherImportersItem mixtureSuppliersAgreementID "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />		
								</#if>
							</#list>
						</#list>
						
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_SUMMARY", "BioSummaryEvaluation") />					
						<#list documentList as document>
							<#if document?has_content>
								<#list document.ReportsAndAdministrativeInformation.SummaryAndEvaluation.PackagingRelatedAttachments as typeOfReportIdentifierItem>
									<#if typeOfReportIdentifierItem?has_content>							
									<@tableRowForSummaryEvaluationTypeOfReport typeOfReportIdentifierItem activeSubstanceSummaryTypeOfReportID "Other substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />	
									</#if>
								</#list>
							</#if>
						</#list>
						
					</#if>	
					</#list>
				</#if>	
			</tbody>					
		</table>		
	</chapter>
		
</book>
	
<!-- Macros and functions -->

<!-- table for attachments in metadata -->	
<#macro tableRowForAttachments document attachments attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if attachments?has_content>
	<tr><?dbfo bgcolor="#87CEFA" ?>
		<!-- Type -->	
		<td><?dbfo bgcolor="#c1f0c1" ?>
			<emphasis role="bold"><para><@com.text type /></para></emphasis>
			<@com.emptyLine/>
			<para>Attachments in the metadata of the document</para>
		</td>
		<!-- Record/Summary Name -->									
		<td>
			<#if attachmentIdentifier?has_content>
			<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
			<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
			</#if>
			<#if documentName?has_content>
			<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
				<#else/>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
			</#if>
		</td>				
		<!-- Annex II/III requirement -->	
		<td>	
			<para><@com.text attachmentIdentifier.annexRequirement /></para>	
		</td>				
		<!-- Section UUID -->
		<td>
			<#if documentUUID?has_content>
				<para><@com.text documentUUID /></para>
				<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>		
			</#if>			
		</td>
	</tr>	
	<tr>
		<!-- Name of attachment -->
		<td>
			<@attachmentName attachments />
		</td>
		
		<!-- Remarks for attachment -->
		<td>
			<@remarksForAttachment attachments />
		</td>
		
		<!-- Type of attachment-->
		<td>					
			<@attachmentMediaType attachments />	
		</td>	
		
		<!-- Size of attachment -->
		<td>
			<@attachmentSize attachments />
		</td>		
	</tr>		
	
</#if>

</#compress>
</#macro>

<!-- table for images -->					
<#macro tableRowForImages document attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if document?has_content>
<#local attachmentPath = "document." + attachmentIdentifier.attachmentNamePath />
<#local attachment = attachmentPath?eval />
		
	<#if attachment?has_content>
			
	<tr><?dbfo bgcolor="#87CEFA" ?>
		<!-- Type -->	
		<td><?dbfo bgcolor="#c1f0c1" ?>
			<emphasis role="bold"><para><@com.text type /></para></emphasis>
			<@com.emptyLine/>
			<para>Illustrations in Endpoint study records</para>
		</td>
		<!-- Record/Summary Name -->									
		<td>
			<#if attachmentIdentifier?has_content>
			<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
			<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
			</#if>
			<#if documentName?has_content>
			<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
				<#else/>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
			</#if>
		</td>				
		<!-- Annex II/III requirement -->	
		<td>
			<para><@com.text attachmentIdentifier.annexRequirement /></para>		
		</td>				
		<!-- Section UUID -->
		<td>
			<#if documentUUID?has_content>
				<para><@com.text documentUUID /></para>
				<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>		
			</#if>			
		</td>
	</tr>	
	<tr>				
		<!-- Names of attachment -->
		<td>
			<@attachmentName attachment />
		</td>		
		<!-- Remarks of attachment-->
		<td>
			<@remarksForAttachment attachment />
		</td>		
		<!-- media type-->
		<td>
			<@attachmentMediaType attachment />
		</td>							
		<!-- Size -->
		<td>
			<@attachmentSize attachment />
		</td>
	</tr>
	<tr>
		<!-- image -->
		<td colspan="4">
			<#assign attachmentKey = attachment />
			<#if attachmentKey?has_content>
			<#assign loadedAttachment = iuclid.getMetadataForAttachment(attachmentKey) />
			<#if loadedAttachment?has_content && loadedAttachment.isImage>
				<#if loadedAttachment.exceedsLimit(10000000)>
					<para><emphasis role="bold">Image size is too big (${loadedAttachment.size} bytes) and cannot be displayed!</emphasis></para>
				<#elseif !iuclid.imageMimeTypeSupported(loadedAttachment.mediaType) />
					<para><emphasis role="bold">Image type (${loadedAttachment.mediaType}) is not yet supported!</emphasis></para>
				<#else/>
					<mediaobject>
						<imageobject>
							<imagedata width="100%" scalefit="1" fileref="data:${loadedAttachment.mediaType};base64,${iuclid.getContentForAttachment(attachmentKey)}" />
						</imageobject>
					</mediaobject>
				</#if>
			</#if>
			</#if>			
		</td>
	</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- table for attached background material -->
<#macro tableRowForBackgroundMaterial backgroundJustificationItem attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if backgroundJustificationItem?has_content>
	<#local attachment = backgroundJustificationItem.AttachedDocument />
	<#local attachmentRemarks =  backgroundJustificationItem.Remarks />
	<#if attachment?has_content>
	
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Attached background material in Endpoint study records</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if attachmentIdentifier?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text attachmentIdentifier.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>		
				</#if>			
			</td>
		</tr>	
		<tr>				
			<!-- Names of attachment -->
			<td >					
				<@attachmentName attachment />
			</td>			
			<!-- Remarks of attachment-->
			<td>
				<@remarksForAttachment attachment />
			</td>			
			<!-- Reason/Purpose or additional remarks for attachment -->
			<td>
				Remarks for the attachment: <@com.text attachmentRemarks />
			</td>	
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>				
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- table for attached study reports -->					
<#macro tableRowForAttachedStudy document attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if document?has_content>
	<#local attachmentPath = "document." + attachmentIdentifier.attachmentNamePath />
	<#local attachment = attachmentPath?eval />	
	<#if attachment?has_content>
	<#list attachment as attachments>
	
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Attached full study reports in Endpoint study records</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if attachmentIdentifier?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>		
				<para><@com.text attachmentIdentifier.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>				
				</#if>			
			</td>
		</tr>			
		<tr>				
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachments />
			</td>				
			<!-- Remarks for attachment -->
			<td>
				<@remarksForAttachment attachments />					
			</td>		
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachments />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachments />
			</td>
		</tr>
	</#list>
	</#if>
</#if>
</#compress>
</#macro>

<!-- data waiving justification table -->
<#macro tableRowForAttachedJustification attachedJustificationItem attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if attachedJustificationItem?has_content>
	<#local attachment = attachedJustificationItem.AttachedJustification />
	<#local attachmentRemarks =  attachedJustificationItem.ReasonPurpose />
	<#if attachment?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Attached justification in Endpoint study records</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if attachmentIdentifier?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text attachmentIdentifier.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>				
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>					
				<@attachmentName attachment />
			</td>			
			<!-- Remarks for attachment-->
			<td>
				<@remarksForAttachment attachment />
			</td>		
			<!-- Reason/Purpose or additional remarks for attachment -->
			<td>
				Additional remarks for attachment: <@com.picklist attachmentRemarks />
			</td>			
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- assigned suppliers table -->
<#macro tableRowForAssignedSuppliers document attachmentIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if document?has_content>
	<#local attachmentPath = "document." + "OnlyRepresentationInfo.NonEUManufacturerAssignment" />
	<#local attachment = attachmentPath?eval />
	<#if attachment?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Assignment from non EU-manufacturer</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if attachmentIdentifier?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text attachmentIdentifier.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text attachmentIdentifier.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text attachmentIdentifier.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>	
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>					
				<@attachmentName attachment />
			</td>			
			<!-- Remarks for attachment-->
			<td>
				<@remarksForAttachment attachment />
			</td>		
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachment />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- other importers table -->
<#macro tableRowForSuppliersOtherImporters otherImportersItem mixtureSuppliersAgreementID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if otherImportersItem?has_content>
	<#local attachment = otherImportersItem.Agreement />
	<#if attachment?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Agreement with other importers</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if mixtureSuppliersAgreementID?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text mixtureSuppliersAgreementID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text mixtureSuppliersAgreementID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text mixtureSuppliersAgreementID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>		
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachment />
			</td>				
			<!-- Remarks for attachment -->
			<td>
				<@remarksForAttachment attachment />					
			</td>				
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachment />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>			
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- related packaging attachment table -->
<#macro tableRowForBioPackaging packagingRelatedAttachmentItem packagingAttachmentID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if packagingRelatedAttachmentItem?has_content>
	<#local attachment = packagingRelatedAttachmentItem />
	<#if attachment.AttachedDocument?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Packaging related attachment</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if packagingAttachmentID?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text packagingAttachmentID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text packagingAttachmentID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text packagingAttachmentID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>				
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachment.AttachedDocument />
			</td>				
			<!-- Remarks for attachment -->
			<td>
				<@remarksForAttachment attachment.AttachedDocument />				
			</td>				
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachment.AttachedDocument />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachment.AttachedDocument />
			</td>			
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- summary and evaluation attachment  -->
<#macro tableRowForSummaryEvaluationAttachment summaryEvaluationAttachmentItem summaryAndEvaluationID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if summaryEvaluationAttachmentItem?has_content>
	<#local attachment = summaryEvaluationAttachmentItem />
	<#if attachment.Attachments?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Summary and evaluation reports and administrative information</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if summaryAndEvaluationID?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text summaryAndEvaluationID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text summaryAndEvaluationID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text summaryAndEvaluationID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>							
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachment.Attachments />
			</td>				
			<!-- Remarks for attachment -->
			<td>
				<@remarksForAttachment attachment.Attachments />					
			</td>				
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachment.Attachments />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachment.Attachments />
			</td>			
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- substance composition attachment  -->
<#macro tableRowForSubstanceComposition attachedDescriptionItem substanceCompositionID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if attachedDescriptionItem?has_content>
	<#local attachment = attachedDescriptionItem.AttachedDocument />
	<#if attachment?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Description of Substance Composition</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if substanceCompositionID?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text substanceCompositionID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text substanceCompositionID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text substanceCompositionID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>					
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachment />
			</td>	
			<!-- remarks-->
			<td>
				<@remarksForAttachment attachment />
			</td>			
			<!-- media type-->
			<td>
				<@attachmentMediaType attachment />
			</td>							
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- analytical determination attachment  -->
<#macro tableRowForAnalyticalDetermination attachedAnalyticalDeterminationItem analyticalDeterminationID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if attachedAnalyticalDeterminationItem?has_content>
	<#local attachment = attachedAnalyticalDeterminationItem.AttachedMethodsResults />
	<#if attachment?has_content>
			
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Attached methods/results for analytical determination</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if analyticalDeterminationID?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text analyticalDeterminationID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text analyticalDeterminationID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>					
				<para><@com.text analyticalDeterminationID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>			
				</#if>			
			</td>
		</tr>	
		<tr>
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachment />
			</td>	
			<!-- remarks-->
			<td>
				<@remarksForAttachment attachment />
			</td>			
			<!-- media type-->
			<td>
				<@attachmentMediaType attachment />
			</td>							
			<!-- Size -->
			<td>
				<@attachmentSize attachment />
			</td>
		</tr>
	</#if>
</#if>
</#compress>
</#macro>

<!-- summary and evaluation section 13: type of report -->					
<#macro tableRowForSummaryEvaluationTypeOfReport typeOfReportIdentifierItem activeSubstanceSummaryTypeOfReportID type="" documentName="" documentUUID="" dossierUUID="">
<#compress>
<#if typeOfReportIdentifierItem?has_content>
	<#local attachmentPath = "typeOfReportIdentifierItem." + "Attachments" />
	<#local attachments = attachmentPath?eval />
		
		<tr><?dbfo bgcolor="#87CEFA" ?>
			<!-- Type -->	
			<td><?dbfo bgcolor="#c1f0c1" ?>
				<emphasis role="bold"><para><@com.text type /></para></emphasis>
				<@com.emptyLine/>
				<para>Attached full study reports in Endpoint study records</para>
			</td>
			<!-- Record/Summary Name -->									
			<td>
				<#if attachmentIdentifier?has_content>
				<para><emphasis role="bold">Section No.</emphasis> <@com.text activeSubstanceSummaryTypeOfReportID.sectionNr /></para>					
				<para><emphasis role="bold">Section Name:</emphasis> <@com.text activeSubstanceSummaryTypeOfReportID.sectionName /></para>				
				</#if>
				<#if documentName?has_content>
				<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
					<#else/>
					<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
				</#if>
			</td>				
			<!-- Annex II/III requirement -->	
			<td>		
				<para><@com.text activeSubstanceSummaryTypeOfReportID.annexRequirement /></para>		
			</td>				
			<!-- Section UUID -->
			<td>
				<#if documentUUID?has_content>
					<para><@com.text documentUUID /></para>
					<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>				
				</#if>			
			</td>
		</tr>			
		<tr>				
			<!-- Names of attachment -->
			<td>
				<@attachmentName attachments />
			</td>				
			<!-- Remarks for attachment -->
			<td>
				<@remarksForAttachment attachments />					
			</td>		
			<!-- Media type -->
			<td>
				<@attachmentMediaType attachments />
			</td>
			<!-- Size -->
			<td>
				<@attachmentSize attachments />
			</td>
		</tr>
</#if>
</#compress>
</#macro>

<!-- Functions to check root of report - substance or mixture -->
<#function checkSubstanceRoot substance>
	<#local substances = []/>
	<#if !(rootDocument.documentType=="SUBSTANCE")>
		<#return [] />
	</#if>	
	<#if rootDocument.documentType=="SUBSTANCE">
		<#return true>
	</#if>	
	<#return substances />
</#function>

<#function checkMixtureRoot mixture>
	<#local mixtures = []/>
	<#if !(rootDocument.documentType=="MIXTURE")>
		<#return [] />
	</#if>	
	<#if rootDocument.documentType=="MIXTURE">
		<#return true>
	</#if>
	<#return mixtures />
</#function>

<!-- Macros for attachments -->
<#macro attachmentName attachments>
<#compress>
	<#assign attachmentData = iuclid.getMetadataForAttachment(attachments) />
	<#if attachmentData?has_content>
		<para><emphasis role="bold">Attachment name: </emphasis></para><para><#escape x as x?html>${attachmentData.filename}</#escape></para>
	</#if>
</#compress>
</#macro>

<#macro remarksForAttachment attachments>
<#compress>
	<#assign attachmentData = iuclid.getMetadataForAttachment(attachments) />
	<#if attachmentData?has_content>
		<para><emphasis role="bold">Attachment remarks:</emphasis></para><para><#escape x as x?html>${attachmentData.remarks}</#escape></para>
		<#else/>
		<emphasis>No remarks for this attachment are provided</emphasis>
	</#if>
</#compress>
</#macro>

<#macro attachmentSize attachments>
<#compress>
	<#assign attachmentData = iuclid.getMetadataForAttachment(attachments) />
	<#if attachmentData?has_content>
		<para><emphasis role="bold">Attachment size: </emphasis></para><para><#escape x as x?html>${attachmentData.size}</#escape></para>
	</#if>
</#compress>
</#macro>

<#macro attachmentMediaType attachments >
<#compress>
	<#assign attachmentData = iuclid.getMetadataForAttachment(attachments) />
	<#if attachmentData?has_content>
		<para><emphasis role="bold">Attachment media type: </emphasis></para><para><#escape x as x?html>${attachmentData.mediaType}</#escape></para>
	</#if>
</#compress>
</#macro>

<#function getActiveSubstanceList mixture>
	<#local substanceList = []/>

	<#local compositionList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />
	
	<#list compositionList as composition>
	<#if composition?has_content>
		<#local componentList = composition.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentActiveSubstance(component)>
				<#local substance = iuclid.getDocumentForKey(component.Reference)/>
				<#if substance?has_content && (substance.documentType=="SUBSTANCE" || substance.documentType=="MIXTURE")>
					<#local substanceList = com.addDocumentToSequenceAsUnique(substance, substanceList)/>	
				</#if>			
			</#if>			
		</#list>
	</#if>
	</#list>
	
	<#return substanceList />
</#function>

<#function isComponentActiveSubstance component>
	<#return component.Function?has_content && com.picklistValueMatchesPhrases(component.Function, ["active substance"]) />
</#function>

<#function getOtherSubstanceList mixture>
	<#local substanceList = []/>

	<#local compositionList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />
	
	<#list compositionList as composition>
	<#if composition?has_content>
		<#local componentList = composition.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentOtherSubstance(component)>
				<#local substance = iuclid.getDocumentForKey(component.Reference)/>
				<#if substance?has_content && (substance.documentType=="SUBSTANCE" || substance.documentType=="MIXTURE")>
					<#local substanceList = com.addDocumentToSequenceAsUnique(substance, substanceList)/>	
				</#if>	
			</#if>
		</#list>
	</#if>
	</#list>
	
	<#return substanceList />
</#function>

<#function isComponentOtherSubstance component>
	<#return component.Function?has_content && com.picklistValueMatchesPhrases(component.Function, ["absorbent", "adsorbent", "anticaking agent", "anticoagulant", "booster", "buffer", "coagulant", "coating agent", "colourant", "complexing agent", "conditioner", "controlled release agent", "crystal growth regulator", "dehydrating agent", "denaturant", "drying agent", "dye", "emulsifier", "filler", "flow aid agent", "fragrance", "hardener", "lubricant",
	 "moisturiser", "neutraliser", "odour masking agent", "pH adjuster", "pigment", "propellant", "solvent", "stabiliser", "stiffener", "UV absorber", "viscosity modifier", "water repellent", "wetting agent", "other:"]) />
</#function>

<#function isImageAttachmentPresent document attachmentIdentifier>

		<#assign attachmentPath = "document." + attachmentIdentifier.attachmentNamePath />
		<#assign attachmentPathImage = attachmentPath?eval />
				
		<#if attachmentPathImage?has_content>
		<#return true />
		<#else/>
		<#return false />
		</#if>
</#function>
<#function isFullStudyAttachmentPresent document attachmentIdentifier>

		<#assign attachmentPath = "document." + attachmentIdentifier.attachmentNamePath />
		<#assign attachmentPathFullStudy = attachmentPath?eval />
				
		<#if attachmentPathFullStudy?has_content>
		<#return true />
		<#else/>
		<#return false />
		</#if>
</#function>
<#function isAssignmentSupplierAttachment document mixtureSuppliersAssignmentID>

		<#assign attachmentPath = "document." + "OnlyRepresentationInfo.NonEUManufacturerAssignment" />
		<#assign attachmentPathSupplier = attachmentPath?eval />
				
		<#if attachmentPathSupplier?has_content>
		<#return true />
		<#else/>
		<#return false />
		</#if>
</#function>