<?xml version="1.0" encoding="UTF-8"?>

<#-- Import common macros and functions -->
<#import "macros_common.ftl" as com>
<#import "macros_csr.ftl" as csr>
<#import "macros_pnec.ftl" as pnec>

<!-- CSR main template file -->
<#assign locale = "en" />
<#assign sysDateTime = .now>

<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

	<#assign substance = rootDocument />
	
	<#assign left_header_text = ''/> 
	<#assign central_header_text = rootDocument.name /> 
	<#assign right_header_text = ''/> 
	
	<#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/> 
	<#assign central_footer_text = 'Chemical Safety Report'/> 
	<#assign right_footer_text = ''/> 
	
	<#assign ownerLegalEntity = iuclid.getDocumentForKey(substance.OwnerLegalEntity) />
	<#assign referenceSubstance = iuclid.getDocumentForKey(substance.ReferenceSubstance.ReferenceSubstance) />
	<#-- Initialize assessment entity related lists -->
	<@csr.initAssessmentEntities substance/>
	
    <info>
        <title>CHEMICAL SAFETY REPORT</title>
		<cover>
            <para>
				<para>
					<emphasis role="bold">Substance Name:</emphasis> <@csr.substanceName substance />
				</para>
				<#if referenceSubstance?has_content>
					<#if referenceSubstance.Inventory.InventoryEntry?has_content>
					<para>		
						<emphasis role="bold">EC Number:</emphasis>
						<@com.inventoryECNumber referenceSubstance.Inventory.InventoryEntry />
					</para>
					</#if>
					<para>
						<emphasis role="bold">CAS Number:</emphasis>
						<#assign casNumberInv>
							<@com.inventoryECCasNumber referenceSubstance.Inventory.InventoryEntry />
						</#assign>
						<#if casNumberInv?has_content>
							${casNumberInv}
						<#else>
							<@com.text referenceSubstance.ReferenceSubstanceInfo.CASInfo.CASNumber />
						</#if>
					</para>
				</#if>	
				<para>
					<emphasis role="bold">Registrant's Identity: </emphasis><#if ownerLegalEntity?has_content><@com.text ownerLegalEntity.GeneralInfo.LegalEntityName/></#if>
				</para>
			</para>
        </cover>
    </info>
	
	<!-- Part A -->
	<part>
		<title>Part A</title>
		
		<#assign recordList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "ChemicalSafetyReport") />
		<#-- print only the first TypeCSRPartA record -->
		<#if recordList?size gt 1>
			<#assign recordList = [recordList[0]]/>
		</#if>
		<#assign printRecordName = false />
		
		<chapter label="1">
			<title role="HEAD-1">SUMMARY OF RISK MANAGEMENT MEASURES</title>
			
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.SummaryRMM/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
			
		</chapter>
		<chapter label="2">
			<title role="HEAD-1">DECLARATION THAT RISK MANAGEMENT MEASURES ARE IMPLEMENTED</title>
			
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.DeclarationRMMImplemented/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
			
		</chapter>
		<chapter label="3">
			<title role="HEAD-1">DECLARATION THAT RISK MANAGEMENT MEASURES ARE COMMUNICATED</title>
			
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.DeclarationRMMCommunicated/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
			
		</chapter>
	</part>
	
	<!-- Part B -->
	<part>
		<title>Part B</title>
		
		<chapter label="1">
			<title role="HEAD-1">IDENTITY OF THE SUBSTANCE AND PHYSICAL AND CHEMICAL PROPERTIES</title>
			
			<#include "01_csr_identity_of_the_substance_and_phys_chem_properties.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="2">
			<title role="HEAD-1">MANUFACTURE AND USES</title>
			
			<#include "02_csr_manufacture_and_use.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="3">
			<title role="HEAD-1">CLASSIFICATION AND LABELLING</title>
			
			<#include "03_csr_classification_and_labelling.ftl" encoding="UTF-8" />
		</chapter>

		<chapter label="4">
			<title role="HEAD-1">ENVIRONMENTAL FATE PROPERTIES</title>
			
			<#include "04_csr_environmental_fate_properties.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="5">
			<title role="HEAD-1">HUMAN HEALTH HAZARD ASSESSMENT</title>
			
			<#include "05_csr_human_health_hazard_assessment.ftl" encoding="UTF-8" />
		</chapter>

		<chapter label="6">
			<title role="HEAD-1">HUMAN HEALTH HAZARD ASSESSMENT OF PHYSICOCHEMICAL PROPERTIES</title>
			
			<#include "06_csr_human_health_hazard_assessment_of_physicochemical_properties.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="7">
			<title role="HEAD-1">ENVIRONMENTAL HAZARD ASSESSMENT</title>
			
			<#include "07_csr_environmental_hazard_assessment.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="8">
			<title role="HEAD-1">PBT AND vPvB ASSESSMENT</title>
			
			<#include "08_csr_pbt_and_vpvb_assessment.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="9">
			<title role="HEAD-1">EXPOSURE ASSESSMENT (and related risk characterisation)</title>
			<para> No information available. </para>
		</chapter>
		
		<chapter label="10">
			<title role="HEAD-1">RISK CHARACTERISATION RELATED TO COMBINED EXPOSURE</title>
			<para> No information available. </para>
		</chapter>
		
	</part>
	
	<!-- Part B -->
	<part>
		<title>Annexes</title>
		
		<chapter label="1">
			<title role="HEAD-1">Annex: References</title>
			
			<#include "Annex1_csr_references.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="2">
			<title role="HEAD-1">Annex: Information on Test Material</title>
			
			<#include "Annex2_csr_information_on_test_material.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="3">
			<title role="HEAD-1">Annex: Mode of action / Human relevance Framework</title>
			
			<#include "Annex3_mode_of_action.ftl" encoding="UTF-8" />
		</chapter>
	</part>

</book>

<!-- Macros and functions -->

<#-- Macros to separate documents into three lists: 'study results', 'data waiving', 'testing proposal' -->

<#macro populateResultAndDataWaivingAndTestingProposalStudyLists studyList>
	<#assign resultStudyList = [] />
	<#assign dataWaivingStudyList = [] />
	<#assign testingProposalStudyList = [] />
	<#if studyList?has_content>
		<#list studyList as study>
			<#if isTestingProposalStudy(study)>
				<#assign testingProposalStudyList = testingProposalStudyList + [study] />
			<#elseif isDataWaivingStudy(study)>
				<#assign dataWaivingStudyList = dataWaivingStudyList + [study] />
			<#elseif isRelevantAdequacyOfStudy(study)>
				<#assign resultStudyList = resultStudyList + [study] />
			</#if>
		</#list>
	</#if>
	<#-- sort resultStudyList according to PurposeFlag -->
	<#assign resultStudyList = iuclid.sortByField(resultStudyList, "AdministrativeData.PurposeFlag", ["key study","supporting study","weight of evidence","disregarded due to major methodological deficiencies","other information"]) />
</#macro>

<#function isRelevantAdequacyOfStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
    <#return PurposeFlag?has_content && !com.picklistValueMatchesPhrases(PurposeFlag, ["other information"]) />
</#function>

<#function isDataWaivingStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
	<#local PurposeFlag = study.AdministrativeData.PurposeFlag />
	<#local DataWaiving = study.AdministrativeData.DataWaiving />
    <#return !(PurposeFlag?has_content) && DataWaiving?has_content />
</#function>

<#function isTestingProposalStudy study>
	<#if !(study?has_content)>
		<#return false>
	</#if>
    <#return com.picklistValueMatchesPhrases(study.AdministrativeData.StudyResultType, ["experimental study planned.*"]) />
</#function>
