<?xml version="1.0" encoding="UTF-8"?>

<#-- Import common macros and functions -->
<#import "macros_common.ftl" as com>
<#-- Include utilities for the list of confidentiality flag identifiers -->
<#include "literature_reference_utilities.ftl" />

<!-- Literature reference template file -->
<#assign locale = "en" />
<#assign sysDateTime = .now>
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

<#assign substance = rootDocument />
<#assign mixture = rootDocument />
	
<#assign substanceDerivation = substance />
<#assign mixtureDerivation = mixture>
<#assign literatureCounter = 0>
<#assign informaltableInitiated = false>

<#assign left_header_text = ''/>

	<#assign mixtureList = checkMixtureRoot(mixture)/>
	<#if mixtureList?has_content>
		<#if mixtureDerivation?has_content>	
		<#assign central_header_text = " Literature References generated from a Mixture/Product (including Literature References in any linked Substance): " + mixtureDerivation.name />
		</#if>
	</#if>
	
	<#assign substanceList = checkSubstanceRoot(substance)/>
	<#if substanceList?has_content>	
		<#if substanceDerivation?has_content>
		<#assign central_header_text = " Literature References generated from Substance: " + substanceDerivation.name />
		</#if>
	</#if>
	
<#assign right_header_text = ''/> 

<#assign left_footer_text = sysDateTime?string[" dd/MM/yyyy "] + " Generated by IUCLID 6 " + iuclid6Version/> 
<#assign central_footer_text = ''/> 
<#assign right_footer_text = ''/> 
	
    <info>
        <title>Literature References Report</title>
		<cover>
            <para>
				
				<@com.emptyLine/>
				
				<!-- Headline information for report generated from a Mixture, derived from the BPR PAR template -->
				<#assign mixtureList = checkMixtureRoot(mixture)/>
				<#if mixtureList?has_content>		
					<!-- Product name(s) IUCLID section 2.3 -->
					<#assign productMixtureName = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />			
					<#if productMixtureName?has_content>
						<para><emphasis role="bold">Product name(s):</emphasis></para> 
						<#list productMixtureName as names>
							<@com.text names.GeneralInformation.Name />
						</#list>
					</#if>
					<@com.emptyLine/>
					<!-- Product type(s) IUCLID section 7.1 -->
					<#assign productType = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "BioIntendedUsesExposure") />			
					<#if productType?has_content>
						<para><emphasis role="bold">Product types(s):</emphasis></para> 
						<#list productType as types>
							<@com.picklistMultiple types.IntendedUsesAndExposure.ProductType />
						</#list>
					</#if>
					<@com.emptyLine/>
					<!-- Active substance name from a substance or a reference substance, not from a linked mixture -->
					<#assign mixtureComposition = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />			
					<#if mixtureComposition?has_content>
						<para><emphasis role="bold">Active substance name:</emphasis></para>
						<#list mixtureComposition as mixtureCompositions>
							<#assign activeSubstance = getActiveSubstanceListForSubstance(mixtureCompositions) />
								<#if activeSubstance?has_content>
									<#list activeSubstance as activeSubstanceName>
										<@com.text activeSubstanceName.ChemicalName />
									</#list>
								</#if>
						</#list>
						<@com.emptyLine/>
						<#list mixtureComposition as mixtureCompositions>
							<#assign activeSubstance = getActiveSubstanceListForReferenceSubstance(mixtureCompositions) />
								<#if activeSubstance?has_content>
									<#list activeSubstance as activeSubstanceName>
										<para><emphasis role="bold">Active substance name (from Reference substance):</emphasis> <@com.text activeSubstanceName.GeneralInfo.ReferenceSubstanceName /></para>
									</#list>
									<#else/> 
								</#if>
						</#list>
					</#if>
				</#if>
			</para>
        </cover>
    </info>
			
	<chapter label="1">
		<title role="HEAD-1">Literature References</title>				
		
		<!-- Literature references (substance) -->
		<#assign substanceList = checkSubstanceRoot(substance)/>
		<#if substanceList?has_content>
			<emphasis role="landscape">
			<table border="1">
				<title>Literature References generated from a Substance</title>
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />			
				<tbody>	
					<tr>								
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Type</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Section information</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold"></emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>			
					
					<#if rootDocument.documentType=="SUBSTANCE">
						<!-- Substance Literature References -->					
						<#list substanceLiteratureReferenceListpart1 as dataSourceIdentifier>
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
							
							<#list documentList as document>
								<#if document?has_content>
								<#list document.DataSource.Reference as referenceItem>
									<#if referenceItem?has_content>
									
									<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
									</#if>									
								</#list>
								</#if>
							</#list>
						</#list>
						
						
						<#list substanceLiteratureReferenceListpart2 as dataSourceIdentifier>
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
														
							<#list documentList as document>
								<#if document?has_content>
								<#list document.DataSource.Reference as referenceItem>
									<#if referenceItem?has_content>
									
									<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
									</#if>									
								</#list>
								</#if>
							</#list>
						</#list>
						
					</#if>					
				</tbody>
			<#if informaltableInitiated>	
				</informaltable>	
			<#else>
				</table>
			</#if>
			</emphasis>
		</#if>
		
		<!-- Literature references (mixture) -->
		<#assign mixtureList = checkMixtureRoot(mixture)/>
		<#if mixtureList?has_content>
		
			<#assign informaltableInitiated = false>
			<emphasis role="landscape">
			<table border="1">
				<title>Literature References generated from a Mixture/Product (including Literature References in any linked Substance)</title>
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />			
				<tbody>
					<tr>								
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Type</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Section information</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
					
					<!-- Biocidal Product Literature References -->							
					<#list mixtureLiteratureReferenceList as dataSourceIdentifier>
						<#assign documentList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
						<#list documentList as document>
							<#if document?has_content>
								<#list document.DataSource.Reference as referenceItem>
									<#if referenceItem?has_content>
										<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Biocidal product" document.name document.documentKey.uuid document.documentKey.snapshotUuid />											
									</#if>
								</#list>
							</#if>
						</#list>							
					</#list>
					
					<!-- Active substance Literature References -->	
					<#assign activeSubstanceList = getActiveSubstanceList(mixture) />
					
					<#list activeSubstanceList as substance>	
					
						<#list substanceLiteratureReferenceListpart1 as dataSourceIdentifier>
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>
									<#list document.DataSource.Reference as referenceItem>
										<#if referenceItem?has_content>											
											<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Active Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
										</#if>									
									</#list>
								</#if>
							</#list>
						</#list>	
					
						<#list substanceLiteratureReferenceListpart2 as dataSourceIdentifier>
								<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
								<#list documentList as document>
									<#if document?has_content>
										<#list document.DataSource.Reference as referenceItem>
											<#if referenceItem?has_content>											
												<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Active Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
											</#if>									
										</#list>
									</#if>
								</#list>
						</#list>
						
					</#list>
					
					<!-- Other substance Literature References -->	
					<#assign otherSubstanceList = getOtherSubstanceList(mixture) />
			
					<#list otherSubstanceList as substance>
					
						<#list substanceLiteratureReferenceListpart1 as dataSourceIdentifier>
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>
									<#list document.DataSource.Reference as referenceItem>
										<#if referenceItem?has_content>											
											<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Other Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
										</#if>									
									</#list>
								</#if>
							</#list>
						</#list>
					
						<#list substanceLiteratureReferenceListpart2 as dataSourceIdentifier>
							<#assign documentList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, dataSourceIdentifier.docType, dataSourceIdentifier.docSubType) />
							<#list documentList as document>
								<#if document?has_content>
									<#list document.DataSource.Reference as referenceItem>
										<#if referenceItem?has_content>											
											<@tableRowForLiteratureReference referenceItem dataSourceIdentifier "Other Substance" document.name document.documentKey.uuid document.documentKey.snapshotUuid />						
										</#if>									
									</#list>
								</#if>
							</#list>
						</#list>
						
					</#list>
					
				</tbody>
				<#if informaltableInitiated>	
					</informaltable>	
				<#else>
					</table>
				</#if>
			</emphasis>
		</#if>
		
	</chapter>
</book>

<!-- Macros and functions -->

<!-- table for Literature References (Substance root) -->					
<#macro tableRowForLiteratureReference referenceItem dataSourceIdentifier type="" documentName="" documentUUID="" dossierUUID="">
<#compress>

	<#if referenceItem?has_content && dataSourceIdentifier?has_content>
		
		<#assign dataSource = iuclid.getDocumentForKey(referenceItem)/>				
		
		<#if dataSource?has_content>
			<tr>
				<!-- Type -->	
				<td colspan="2"><?dbfo bgcolor="#c1f0c1" ?>
					<para><@com.text type /></para>
				</td>
				
				<!-- Record/Summary Name -->									
				<td colspan="2">				
					<para><emphasis role="bold">Section No.</emphasis> <@com.text dataSourceIdentifier.sectionNr /></para>					
					<para><emphasis role="bold">Section Name:</emphasis> <@com.text dataSourceIdentifier.sectionName /></para>
					<#if documentName?has_content>
						<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text documentName /></para>
						<#else/>
							<para><emphasis role="bold">Name given to the Document:</emphasis> <@com.text document.name /></para>
					</#if>
				</td>
				
				<!-- Annex II/III requirement -->	
				<td colspan="2">
					<para><@com.text dataSourceIdentifier.AnnexIIIrequirements /></para>
				</td>
				
				<!-- Section UUID -->
				<td colspan="2">
					<#if documentUUID?has_content>
						<para><@com.text documentUUID /></para>
						<para><citetitle><ulink url="http://localhost:8080/webstart/launch.jnlp?uuid=${documentUUID}&amp;snapshot=${dossierUUID}">
						</ulink></citetitle></para>		
					</#if>			
				</td>
			</tr>
			
			<tr>
				<!-- Reference type -->
				<td>
					<#if dataSource.GeneralInfo.LiteratureType?has_content>
					Reference type: <@com.picklist dataSource.GeneralInfo.LiteratureType />
						<#else/>
							Reference type: <emphasis>No reference type provided</emphasis>
					</#if>
				</td>
				<!-- Title -->
				<td>
					<#if dataSource.GeneralInfo.Name?has_content>
					Title: <@com.text dataSource.GeneralInfo.Name />	
						<#else/>
							Title: <emphasis>No title provided</emphasis>
					</#if>
				</td>				
				<!-- Author-->
				<td>					
					<#if dataSource.GeneralInfo.Author?has_content>
					Author: <@com.text dataSource.GeneralInfo.Author />	
						<#else/>
							Author:<emphasis>No author provided</emphasis>
					</#if>
				</td>	
				<!-- Bibliographic source -->
				<td>
					<#if dataSource.GeneralInfo.Source?has_content>
					Bibliographic source: <@com.text dataSource.GeneralInfo.Source />
						<#else/>
							Bibliographic source:<emphasis> No bibliographic source provided</emphasis>
					</#if>
					
					<@com.emptyLine/>
					
					<#if dataSource.GeneralInfo.ReferenceYear?has_content>
					Year: <@com.number dataSource.GeneralInfo.ReferenceYear />		
						<#else/>
							Year: <emphasis>No year provided</emphasis>
					</#if>
				</td>
				<!-- Testing laboratory -->
				<td>
					<#if dataSource.GeneralInfo.TestLab?has_content>
					Testing laboratory: <@com.text dataSource.GeneralInfo.TestLab />	
						<#else/>
							Testing facility: <emphasis>No testing laboratory provided</emphasis>
					</#if>
				</td>
				<!-- Report no. -->
				<td>
					<#if dataSource.GeneralInfo.ReportNo?has_content>
					Report no. <@com.text dataSource.GeneralInfo.ReportNo />
						<#else/>
							Report no.:<emphasis> No report number provided</emphasis>
					</#if>		
				</td>
				<!-- Company owner / Company study no. -->
				<td>
					<#if dataSource.GeneralInfo.CompanyOwner?has_content>
					Company owner: <@com.text dataSource.GeneralInfo.CompanyOwner />
						<#else/>
							Study sponsor:<emphasis> No company owner provided</emphasis>
					</#if>
									
					<@com.emptyLine/>
					
					<#if dataSource.GeneralInfo.CompanyOwnerStudyNo?has_content>
					Company study number: <@com.text dataSource.GeneralInfo.CompanyOwnerStudyNo />
						<#else/>
							Study number: <emphasis>No company study number provided</emphasis>
					</#if>
				</td>
				<!-- Report date -->
				<td>
					<#if dataSource.GeneralInfo.ReportDate?has_content>
					Report date: <@com.text dataSource.GeneralInfo.ReportDate />
						<#else/>
							Report date: <emphasis>No report date provided</emphasis>
					</#if>
				</td>
			</tr>
				
			<tr>
				<!-- Remarks -->
				<td colspan="8">
					<#if dataSource.GeneralInfo.Remarks?has_content>
						Remarks: <@com.text dataSource.GeneralInfo.Remarks />
						<#else/>
							Remarks: <emphasis>no remarks in literature reference</emphasis>
					</#if>
				</td>
			</tr>
		</#if>
	</#if>

	<#assign literatureCounter = literatureCounter+1>
	<!-- literatureCounter = ${literatureCounter}-->
	<#if literatureCounter==99>
		<#assign literatureCounter = 0>
		<!-- for every 100 literature references, create new table -->
			
			</tbody>
		<#if informaltableInitiated>	
			</informaltable>	
		<#else>
			</table>
		</#if>
		</emphasis>
			
		<#assign informaltableInitiated = true>
		<emphasis role="landscape">
			<informaltable border="1">
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />
				<col width="12.5%" />			
				<tbody>
					<tr>								
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Type</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Section information</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">Annex II/III requirement</emphasis></th>
						<th colspan="2"><?dbfo bgcolor="#87CEFA" ?><emphasis role="bold">UUID</emphasis></th>					
					</tr>		
	</#if>
</#compress>
</#macro>

<#function checkSubstanceRoot substance>
	<#local substances = []/>
	<#if !(rootDocument.documentType=="SUBSTANCE")>
		<#return [] />
	</#if>
	
	<#if rootDocument.documentType=="SUBSTANCE">
		<#return true>
	</#if>
	
	<#return substances />
</#function>

<#function checkMixtureRoot mixture>
	<#local mixtures = []/>
	<#if !(rootDocument.documentType=="MIXTURE")>
		<#return [] />
	</#if>
	
	<#if rootDocument.documentType=="MIXTURE">
		<#return true>
	</#if>
	
	<#return mixtures />
</#function>

<#function getActiveSubstanceListForReferenceSubstance mixtureCompositions>
	<#local substanceList = []/>
	
		<#local componentList = mixtureCompositions.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentActiveSubstance(component)>
				<#local referenceSubstance = iuclid.getDocumentForKey(component.Reference)/>
				<#if !(referenceSubstance)?has_content>
					<#return [] />
				</#if>
				<#if substance.documentType=="SUBSTANCE" || substance.documentType=="MIXTURE">
					<#return [] />
				</#if>
				<#if referenceSubstance.documentType=="REFERENCE_SUBSTANCE" >
					<#local substanceList = com.addDocumentToSequenceAsUnique(referenceSubstance, substanceList)/>
				</#if>							
			</#if>			
		</#list>
	
	<#return substanceList />
</#function>

<#function getActiveSubstanceListForSubstance mixtureCompositions>
	<#local substanceList = []/>
	
		<#local componentList = mixtureCompositions.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentActiveSubstance(component)>
				<#local substance = iuclid.getDocumentForKey(component.Reference)/>
				<#if substance?has_content && (substance.documentType=="SUBSTANCE")>
					<#local substanceList = com.addDocumentToSequenceAsUnique(substance, substanceList)/>	
				</#if>
			</#if>
		</#list>
	
	<#return substanceList />
</#function>

<#function getOtherSubstanceList mixture>
	<#local substanceList = []/>

	<#local compositionList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />
	
	<#list compositionList as composition>
		<#local componentList = composition.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentOtherSubstance(component)>
				<#local substance = iuclid.getDocumentForKey(component.Reference)/>
				<#if substance?has_content && (substance.documentType=="SUBSTANCE" || substance.documentType=="MIXTURE")>
					<#local substanceList = com.addDocumentToSequenceAsUnique(substance, substanceList)/>	
				</#if>	
			</#if>
		</#list>
	</#list>
	
	<#return substanceList />
</#function>

<#function isComponentOtherSubstance component>
	<#return component.Function?has_content && com.picklistValueMatchesPhrases(component.Function, ["absorbent", "adsorbent", "anticaking agent", "anticoagulant", "booster", "buffer", "coagulant", "coating agent", "colourant", "complexing agent", "conditioner", "controlled release agent", "crystal growth regulator", "dehydrating agent", "denaturant", "drying agent", "dye", "emulsifier", "filler", "flow aid agent", "fragrance", "hardener", "lubricant",
	 "moisturiser", "neutraliser", "odour masking agent", "pH adjuster", "pigment", "propellant", "solvent", "stabiliser", "stiffener", "UV absorber", "viscosity modifier", "water repellent", "wetting agent", "other:"]) />
</#function>

<#function getActiveSubstanceList mixture>
	<#local substanceList = []/>

	<#local compositionList = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />
	
	<#list compositionList as composition>
		<#local componentList = composition.Components.Components/>
	
		<#list componentList as component>
			<#if isComponentActiveSubstance(component)>
				<#local substance = iuclid.getDocumentForKey(component.Reference)/>
				<#if substance?has_content && (substance.documentType=="SUBSTANCE" || substance.documentType=="MIXTURE")>
					<#local substanceList = com.addDocumentToSequenceAsUnique(substance, substanceList)/>	
				</#if>		
			</#if>			
		</#list>
	</#list>
	
	<#return substanceList />
</#function>

<#function isComponentActiveSubstance component>
	<#return component.Function?has_content && com.picklistValueMatchesPhrases(component.Function, ["active substance"]) />
</#function>