﻿<?xml version="1.0" encoding="UTF-8"?>

<#-- pre-SIEF GHS information -->

<#-- Import common macros and functions -->
<#import "macros_common.ftl" as com>

<#assign locale = "en" />
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

<#assign substance = rootDocument />
		
	<info>
		<title>Classification and labelling information of the lead registrant</title>
		
		<cover>
		<@com.emptyLine/>
			<para><emphasis role="bold">Substance name:</emphasis> <@com.text substance.name/></para>
			<para><emphasis role="bold">Public name of substance:</emphasis> <@com.text substance.PublicName/></para>
		</cover>
	</info>
	
	<chapter>	
		<title>Classification and labelling information of the lead registrant for use by the pre-SIEF</title>
		
		<#assign recordList = iuclid.getSectionDocumentsForParentKey(substance.documentKey, "FLEXIBLE_RECORD", "Ghs") />
		<#assign referenceSubstance = iuclid.getDocumentForKey(substance.ReferenceSubstance.ReferenceSubstance)/>
		
		<#if !recordList?has_content>
			No GHS information available
			<#else/>
			<#list recordList as record>
			
				<informaltable Frame="sides">
				<col width="35%" />
				<col width="65%" />
				<tbody>	
					<tr><?dbfo bgcolor="#EEEEEE" ?>
						<td colspan="2">
							<emphasis role="bold">GHS record name:</emphasis> <@com.text record.name />
						</td>								
					</tr>
					<tr><?dbfo bgcolor="#EEEEEE" ?>
						<td>
							<emphasis role="bold">Substance identity</emphasis>
						</td>					
						<td>
						<emphasis role="bold"><phrase role="red">Hazard classification and labelling</phrase></emphasis>
						</td>										
					</tr>
					
					<tr><?dbfo bgcolor="#EEEEEE" ?>
							<td>
								<#if referenceSubstance?has_content>
									<emphasis role="bold">EC number:</emphasis> <@inventoryECNumber referenceSubstance.Inventory.InventoryEntry />
								</#if>
							</td>
						<td>
							<#assign cb = record.GeneralInformation.NotClassified />
							GHS name: <@classificationSubstanceName record substance />
							<#if cb>
							(not classified)
								<#else/>
								(classified)
							</#if>
						</td>
					</tr>
					
					<tr><?dbfo bgcolor="#EEEEEE" ?>
						<td>
							<#if referenceSubstance?has_content>
								<emphasis role="bold">CAS number:</emphasis> <@com.text referenceSubstance.ReferenceSubstanceInfo.CASInfo.CASNumber/>
							</#if>
						</td>
						<td>		
							<#if !(record.GeneralInformation.Implementation?has_content)>
							No implementation data provided
								<#else/>
									Implementation: <@com.picklist record.GeneralInformation.Implementation/>
							</#if>
						</td>
					</tr>
					<tr><?dbfo bgcolor="#EEEEEE" ?>
						<td>
							<#if referenceSubstance?has_content>
								<emphasis role="bold">Molecular formula:</emphasis> <@com.text referenceSubstance.MolecularStructuralInfo.MolecularFormula/>
							</#if>
							
							<!-- Structural formula -->
							<#if referenceSubstance?has_content>
							<#assign attachmentKey = referenceSubstance.MolecularStructuralInfo.StructuralFormula />
							<#if attachmentKey?has_content>
								<#assign structuralFormula = iuclid.getMetadataForAttachment(attachmentKey) />
								<#if structuralFormula?has_content && structuralFormula.isImage>
									<@com.emptyLine/>
									<para><emphasis role="bold">Structural formula:</emphasis></para>
									<#if structuralFormula.exceedsLimit(10000000)>
										<para><emphasis role="bold">Image size is too big (${structuralFormula.size} bytes) and cannot be displayed!</emphasis></para>
									<#elseif !iuclid.imageMimeTypeSupported(structuralFormula.mediaType) />
										<para><emphasis role="bold">Image type (${structuralFormula.mediaType}) is not yet supported!</emphasis></para>
									<#else/>
										<mediaobject>
											<imageobject>
												<imagedata width="80%" scalefit="1" fileref="data:${structuralFormula.mediaType};base64,${iuclid.getContentForAttachment(attachmentKey)}" />
											</imageobject>
										</mediaobject>
									</#if>
								</#if>
							</#if>
							</#if>
						</td>
						
						<td>
							<#if record.GeneralInformation.TypeClassification?has_content>
								<para>Type of classification: <@com.picklist record.GeneralInformation.TypeClassification/></para>
								<?linebreak?>								
							</#if>	
							
							<#list record.GeneralInformation.RelatedCompositions.Composition as composition>
							<#assign impuritiesAndAdditives = iuclid.getDocumentForKey(composition)/>
								<#if isAdditivesImpuritiesPopulated(impuritiesAndAdditives)>						
									<#if isRelevantForClassification(impuritiesAndAdditives)>	
										<para><phrase role="blue">For the linked composition: <phrase role="black"><emphasis role="HEAD-WoutNo"><@com.text impuritiesAndAdditives.GeneralInformation.Name/></emphasis></phrase> the registrant has indicated that the substance classification is affected by impurities or additives</phrase></para>
										<#else/>
										<para><phrase role="blue">For the linked composition: <phrase role="black"><emphasis role="HEAD-WoutNo"><@com.text impuritiesAndAdditives.GeneralInformation.Name/></emphasis></phrase> the registrant has <phrase role="black"><emphasis role="bold">NOT</emphasis></phrase> indicated that the substance classification is affected by impurities or additives</phrase></para>
									</#if>
								</#if>
							</#list>
							<@com.emptyLine/>
							<@HazardPictogramList record.Labelling.HazardPictogramBlock.HazardPictogram/>
								
							<para role="indent">
								Signal word: <@com.picklist record.Labelling.SignalWord/>
							</para>
						</td>
					</tr>
				</tbody>
				<!-- Labelling section -->
				<tbody>
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">
							<para><emphasis role="bold">Labelling</emphasis></para>
						</td>
					</tr>		
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">	
							<#if record.Labelling.HazardStatementsBlock.HazardStatements?has_content>
									<emphasis role="bold">Hazard statements:</emphasis>
									<@HazardStatementList record.Labelling.HazardStatementsBlock.HazardStatements/>		
							</#if>
						</td>			
					</tr>
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">				
							<#if record.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements?has_content>
									<emphasis role="bold">Precautionary statements:</emphasis>
									<@PrecautionaryStatementsList record.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements/>	
							</#if>
						</td>
					</tr>		
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">		
							<#if record.Labelling.LabelingRequirementsBlock.LabelingRequirements?has_content>
									<emphasis role="bold">Additional labelling requirements (CLP supplemental hazard statement):</emphasis>
									<@SupplimentalHazardStatementList record.Labelling.LabelingRequirementsBlock.LabelingRequirements/>
							</#if>
						</td>
					</tr>
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">		
							<#if record.Labelling.LabelingRequirementsBlock.AdditionalLabelling?has_content>
									<emphasis role="bold">Additional labelling:</emphasis>
									<@AdditionalLabellingList record.Labelling.LabelingRequirementsBlock.AdditionalLabelling/>
							</#if>
						</td>
					</tr>		
					<tr><?dbfo bgcolor="#AFD8EB" ?>
						<td colspan="2">		
							<#if record.NotesBlock.Notes?has_content>
								<para>
									<emphasis role="bold">Notes:</emphasis>
									<para><@NotesLabellingList record.NotesBlock.Notes/></para>
								</para>
							</#if>		
						</td>
					</tr>
				</tbody>
			</informaltable>
				
			<table border="1">
				<col width="25%" />
				<col width="23%" />
				<col width="28%" />
				<col width="24%" />
				<tbody>
					
				<#assign classToBlockMap = {
					"Explosives:" : record.Classification.PhysicalHazards.Explosives,
					"Desensitised explosives:" : record.Classification.PhysicalHazards.DesensitizedExplosives,
					"Flammable gases and chemically unstable gases:" : record.Classification.PhysicalHazards.FlammableGases,
					"Flammable aerosols:" : record.Classification.PhysicalHazards.FlammableAerosols,
					"Oxidising gases:" : record.Classification.PhysicalHazards.OxidisingGases,
					"Gases under pressure:" : record.Classification.PhysicalHazards.GasesPres,
					"Flammable liquids:" : record.Classification.PhysicalHazards.FlammableLiquids,
					"Flammable solids:" : record.Classification.PhysicalHazards.FlammableSolids,
					"Self-reactive substances and mixtures:" : record.Classification.PhysicalHazards.SelfReactiveSubstMixt,
					"Pyrophoric liquids:" : record.Classification.PhysicalHazards.PyrophoricLiquids,
					"Pyrophoric solids:" : record.Classification.PhysicalHazards.PyrophoricSolids,
					"Self-heating substances and mixtures:" : record.Classification.PhysicalHazards.SelfHeatSubstMixt,
					"Substances and mixtures which in contact with water emit flammable gases:" : record.Classification.PhysicalHazards.SubstMixtWater,
					"Oxidising liquids:" : record.Classification.PhysicalHazards.OxidisingLiquids,
					"Oxidising solids:" : record.Classification.PhysicalHazards.OxidisingSolids,
					"Organic peroxides:" : record.Classification.PhysicalHazards.OrganicPeroxides,
					"Corrosive to metals:" : record.Classification.PhysicalHazards.CorMetals
				}/>
					
					<#assign hazardClasses = classToBlockMap?keys />
					<#if hazardClasses?has_content>
						<tr>
							<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
							Classification and labelling according to CLP / GHS for physical hazards
							</td>
						</tr>
						<tr>
							<td><emphasis role="bold">Hazard class</emphasis></td>
							<td><emphasis role="bold">Hazard category</emphasis></td>
							<td><emphasis role="bold">Hazard statement</emphasis></td>
							<td><emphasis role="bold">Reason for no classification</emphasis></td>
						</tr>
					
						<#list hazardClasses as hazardClass>
							<#assign block = classToBlockMap[hazardClass] />
							
							<#if isNotEmptyClassificationBlock(block)>
								
								<tr>
									<!-- Hazard class -->
									<td>
										${hazardClass!}
									</td>
									<!-- Hazard category -->
									<td>
										<@com.picklist block.HazardCategory/>
									</td>
									<!-- Hazard statement -->
									<td>
										<@com.picklist block.HazardStatement/>
									</td>
									<!-- Reason for no classification -->
									<td>
										<@com.picklist block.ReasonForNoClassification/> 
									</td>
								</tr>
							<#else/>
								<tr>
									<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
									Classification and labelling according to CLP / GHS for physicochemical properties
									</td>
								</tr>
								<tr>
									<td colspan="4">
									No Classification and labelling provided for physical hazards
									</td>
								</tr>
							</#if>
						</#list>
					</#if>
					
					<tr>
						<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
						Classification and labelling according to CLP / GHS for health hazards
						</td>
					</tr>
					<tr>
						<td><emphasis role="bold">Hazard class</emphasis></td>
						<td><emphasis role="bold">Hazard category</emphasis></td>
						<td><emphasis role="bold">Hazard statement</emphasis></td>
						<td><emphasis role="bold">Reason for no classification</emphasis></td>
					</tr>
						
					<#assign classToBlockMap = {
						"Acute toxicity - oral:" : record.Classification.HealthHazards.AcuteToxicityOral,
						"Acute toxicity - dermal:" : record.Classification.HealthHazards.AcuteToxicityDermal,
						"Acute toxicity - inhalation:" : record.Classification.HealthHazards.AcuteToxicityInhalation,
						"Skin corrosion / irritation:" : record.Classification.HealthHazards.Irritation,
						"Serious damage / eye irritation:" : record.Classification.HealthHazards.EyeIrritation,
						"Respiratory sensitisation:" : record.Classification.HealthHazards.RespiratorySensitisation,
						"Skin sensitisation:" : record.Classification.HealthHazards.SkinSensitisation,
						"Aspiration hazard:" : record.Classification.HealthHazards.AspirationHazard,
						"Reproductive Toxicity:" : record.Classification.HealthHazards.ReproductiveToxicity.ReproductiveToxicity,
						"Reproductive Toxicity: Effects on or via lactation:" : record.Classification.HealthHazards.ReproductiveToxicity.Effects,
						"Germ cell mutagenicity:" : record.Classification.HealthHazards.GermCell.GermCell,
						"Carcinogenicity:" : record.Classification.HealthHazards.Carcinogenicity.Carcinogenicity
					}/>
					<#assign hazardClasses = classToBlockMap?keys />
					
					<#list hazardClasses as hazardClass>
						<#assign block = classToBlockMap[hazardClass] />
						<#if isNotEmptyClassificationBlock(block)>
							<tr>
								<!-- Hazard class -->
								<td>
									${hazardClass!}
								</td>
								<!-- Hazard category -->
								<td>
									<@com.picklist block.HazardCategory/>
									<#if block.hasElement("SpecificEffect") && block.SpecificEffect?has_content>
										<para>
											Specific effect: <@com.text block.SpecificEffect/>
										</para>
									</#if>
									<#if block.hasElement("RouteExposure") && block.RouteExposure?has_content>
										<para>
											Route of exposure: <@com.picklist block.RouteExposure/>
										</para>
									</#if>
								</td>
								<!-- Hazard statement -->
								<td>
									<@com.picklist block.HazardStatement/>
								</td>
								<!-- Reason for no classification -->
								<td>
									<@com.picklist block.ReasonForNoClassification/> 
								</td>
							</tr>
						</#if>
					</#list>
					
					<#assign usespan = true />
					<#list record.Classification.HealthHazards.ToxicitySingle.Toxicity as item>
						<tr>
							<!-- Hazard class -->
							<#if usespan>
								<td rowspan="${record.Classification.HealthHazards.ToxicitySingle.Toxicity?size}">
									Specific target organ toxicity – single exposure:
								</td>
								<#assign usespan = false />
							</#if>
							<!-- Hazard category -->
							<td>
								<para>
									<@com.picklist item.Toxicity.HazardCategory/> 
								</para>
								<para>
									Affected organs: <@com.text item.Toxicity.Organs/> 
								</para>
								<para>
									Route of exposure: <@com.picklist item.Toxicity.RouteExposure/> 
								</para>
							</td>
							<!-- Hazard statement -->
							<td>
								<@com.picklist item.Toxicity.HazardStatement/>
							</td>
							<!-- Reason for no classification -->
							<td>
								<@com.picklist item.Toxicity.ReasonForNoClassification/>
							</td>
						</tr>
					</#list>
					
					<#assign usespan = true />
					<#list record.Classification.HealthHazards.ToxicityRepeated.Toxicity as item>
						<tr>
							<!-- Hazard class -->
							<#if usespan>
								<td rowspan="${record.Classification.HealthHazards.ToxicityRepeated.Toxicity?size}">
									Specific target organ toxicity – repeated exposure:
								</td>
								<#assign usespan = false />
							</#if>
							<!-- Hazard category -->
							<td>
								<para>
									<@com.picklist item.Toxicity.HazardCategory/> 
								</para>
								<para>
									Affected organs: <@com.text item.Toxicity.Organs/> 
								</para>
								<para>
									Route of exposure: <@com.picklist item.Toxicity.RouteExposure/> 
								</para>
							</td>
							<!-- Hazard statement -->
							<td>
								<@com.picklist item.Toxicity.HazardStatement/>
							</td>
							<!-- Reason for no classification -->
							<td>
								<@com.picklist item.Toxicity.ReasonForNoClassification/>
							</td>
						</tr>
					</#list>
						
					<tr>
						<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
						Specific concentration limits:
						</td>
					</tr>
								
					<#list record.Classification.SpecificConcentrations.ConcentrationRange as item>
						<#if isNotEmptyConcentrationBlock(item)>
							<tr>
								<td colspan="2"><emphasis role="bold">Concentration (%)</emphasis></td>
								<td colspan="2"><emphasis role="bold">Classification</emphasis></td>
							</tr>							
							<tr>
								<!-- Concentration (%) -->
								<td colspan="2">
									<@com.range item.ConcentrationRangeVal/>					
								</td>
								<!-- Classification -->
								<td colspan="2">
									<@com.picklistMultiple item.HazardCategories/>
								</td>
							</tr>
						</#if>
					</#list>
					
					<tr>
						<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
						Classification and labelling according to CLP / GHS for environmental hazards
						</td>
					</tr>
					<tr>
						<td><emphasis role="bold">Hazard class</emphasis></td>
						<td><emphasis role="bold">Hazard category</emphasis></td>
						<td><emphasis role="bold">Hazard statement</emphasis></td>
						<td><emphasis role="bold">Reason for no classification</emphasis></td>
					</tr>
						
					<#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm)>
						<tr>
							<!-- Hazard class -->
							<td>
								Hazards to the aquatic environment (acute/short-term):
							</td>
							<!-- Hazard category -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardCategory/>
							</td>
							<!-- Hazard statement -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardStatement/>
							</td>
							<!-- Reason for no classification -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.ReasonForNoClassification/> 
							</td>
						</tr>
					</#if>
					
					<#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm)>
						<tr>
							<!-- Hazard class -->
							<td>
								Hazards to the aquatic environment (chronic/long-term):
							</td>
							<!-- Hazard category -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardCategory/>
							</td>
							<!-- Hazard statement -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardStatement/>
							</td>
							<!-- Reason for no classification -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.ReasonForNoClassification/> 
							</td>
						</tr>
					</#if>
					
					<!-- M-Factor acute -->
					<tr>
						<td colspan="4"><?dbfo bgcolor="#A0C982" ?>
							M-Factor acute: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorAcute/>
						</td>
					</tr>
				
					<!-- M-Factor chronic -->
					<tr>
						<td colspan="4"><?dbfo bgcolor="#A0C982" ?>
							M-Factor chronic: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorChronic/>
						</td>
					</tr>

					<#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone)>
						<tr>
							<!-- Hazard class -->
							<td>
								Hazardous to the ozone layer:
							</td>
							<!-- Hazard category -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.HazardCategory/>
							</td>
							<!-- Hazard statement -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.HazardStatement/>
							</td>
							<!-- Reason for no classification -->
							<td>
								<@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.ReasonForNoClassification/> 
							</td>
						</tr>
					</#if>
						
					<#if (record.Classification.AdditionalHazard.Classes?has_content) && (record.Classification.AdditionalHazard.Statements?has_content)>
						<tr>
							<td colspan="4"><?dbfo bgcolor="#87CEFA" ?>
							Classification and labelling according to CLP / GHS for additional hazard classes
							</td>
						</tr>			
						<tr>
							<!-- Additional hazard classes -->
							<td colspan="2">
								Additional hazard classes:
							</td>
							<td colspan="2">
								<@com.text record.Classification.AdditionalHazard.Classes/>
							</td>
						</tr>																
						<tr>		
							<!-- Additional hazard statements -->
							<td colspan="2">
								Additional hazard statements:
							</td>							
							<td colspan="2">
								<@com.text record.Classification.AdditionalHazard.Statements/>
							</td>
						</tr>
					</#if>
				</tbody>
			</table>
			
		</#list>
	
	</#if>		
</chapter>
		
</book>

<!-- Macros and functions -->
<#macro inventoryECNumber inventoryBlock>
<#compress>
	<#if inventoryBlock?has_content>
		<#list inventoryBlock as item>
			<#if item.inventoryCode == 'EC'>
				<@com.text item.numberInInventory/>
				<#break>
			</#if>
		</#list>
	</#if>
</#compress>
</#macro>

<#macro classificationSubstanceName ghsOrDsdDpdRecord, substance>
<#compress>
	<#if ghsOrDsdDpdRecord.GeneralInformation.Name?has_content>
		<@com.text ghsOrDsdDpdRecord.GeneralInformation.Name/>
	<#else/>
		<@substanceName substance />
  	</#if>
</#compress>
</#macro>

<#macro HazardPictogramList HazardPictogramRepeatableBlock>
<#compress>
	<#if HazardPictogramRepeatableBlock?has_content>
		<para role="indent"><#list HazardPictogramRepeatableBlock as blockItem>
				<@com.picklist blockItem.Code/>
				<#if blockItem.Code.code?has_content>
					<#assign phraseImageMeta = iuclid.getImageMetadataForPhraseCode(blockItem.Code.code) />					
					<#if phraseImageMeta?has_content>
						<#assign phraseImagePrinted = false/> 
						<#if iuclid.imageMimeTypeSupported(phraseImageMeta.mediaType)>
							<#assign phraseImagePrinted = true/> 					
							<mediaobject>
								<imageobject>
									<imagedata fileref="data:${phraseImageMeta.mediaType};base64,${iuclid.getImageContentForPhraseCode(phraseImageMeta.code, phraseImageMeta.mediaType)}" />
								</imageobject>
							</mediaobject>						
						</#if>
						<#if !phraseImagePrinted>
							<para><emphasis role="bold">The image for phrase code ${blockItem.Code.code} is in an unsupported format!</emphasis></para>
						</#if>
					<#else/>
						<para><emphasis role="bold">No image found for phrase code ${blockItem.Code.code}</emphasis></para>
					</#if>
				</#if>	
		</#list>
		</para>
  	</#if>
</#compress>
</#macro>

<#macro HazardStatementList HazardStatementRepeatableBlock>
<#compress>
	<#if HazardStatementRepeatableBlock?has_content>
		<#list HazardStatementRepeatableBlock as blockItem>
			<para role="indent">
				<@com.picklist blockItem.HazardStatement/>
				<#if blockItem.AdditionalText?has_content>
					(<@com.text blockItem.AdditionalText/>)
				</#if>
			</para>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro PrecautionaryStatementsList PrecautionaryStatementRepeatableBlock>
<#compress>
	<#if PrecautionaryStatementRepeatableBlock?has_content>
		<#list PrecautionaryStatementRepeatableBlock as blockItem>
			<para role="indent">
				<@com.picklist blockItem.PrecautionaryStatement/>
				<#if blockItem.AdditionalText?has_content>
					(<@com.text blockItem.AdditionalText/>)
				</#if>
			</para>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro SupplimentalHazardStatementList SupplimentalHazardStatementRepeatableBlock>
<#compress>
	<#if SupplimentalHazardStatementRepeatableBlock?has_content>
		<#list SupplimentalHazardStatementRepeatableBlock as blockItem>
			<para role="indent">
				<@com.picklist blockItem.SupplHazardStatement/>
				<#if blockItem.AdditionalText?has_content>
					(<@com.text blockItem.AdditionalText/>)
				</#if>
			</para>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro AdditionalLabellingList AdditionalLabellingRepeatableBlock>
<#compress>
	<#if AdditionalLabellingRepeatableBlock?has_content>
		<#list AdditionalLabellingRepeatableBlock as blockItem>
			<para role="indent">
				<@com.text blockItem.Labelling/>
			</para>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro NotesLabellingList NotesRepeatableBlock>
<#compress>
	<#if NotesRepeatableBlock?has_content>
		<#list NotesRepeatableBlock as blockItem>
			<para role="indent">
				<@com.picklist blockItem.Note/>
			</para>
		</#list>
  	</#if>
</#compress>
</#macro>

<#function isNotEmptyClassificationBlock block>
	<#if !(block?has_content)>
		<#return false>
	</#if>
	<#if block.HazardCategory?has_content || block.HazardStatement?has_content || block.ReasonForNoClassification?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function isNotEmptyConcentrationBlock record>
	<#if !(record?has_content)>
		<#return false>
	</#if>
	<#if record.ConcentrationRangeVal?has_content || record.HazardCategories?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function isAdditivesImpuritiesPopulated impuritiesAndAdditives>
	<#local additives = impuritiesAndAdditives.Additives.Additives />
	<#if additives?has_content>
		<#return true />
	</#if>
	
	<#local impurities = impuritiesAndAdditives.Impurities.Impurities />
	<#if impurities?has_content>
		<#return true />
	</#if>
	
		<#return false>
</#function>

<#function isRelevantForClassification impuritiesAndAdditives>
	<#local additives = impuritiesAndAdditives.Additives.Additives />
	<#list additives as additivesList>
		<#if additivesList?has_content>
			<#local cb = additivesList.RelevantForClassificationLabeling />
			<#if cb>
				<#return true />
			</#if>
		</#if>
	</#list>
	
	<#local impurities = impuritiesAndAdditives.Impurities.Impurities />
	<#list impurities as impuritiesList>
		<#if impuritiesList?has_content>
			<#local cb = impuritiesList.RelevantForClassificationLabeling />
			<#if cb>
				<#return true />
			</#if>
		</#if>
	</#list>
	
		<#return false>
</#function>

<#macro substanceName substance>
<#compress>
	<#if substance.ReferenceSubstance.ReferenceSubstance?has_content> 
		<#local referenceSubstance = iuclid.getDocumentForKey(substance.ReferenceSubstance.ReferenceSubstance) />
	</#if>
	<#if referenceSubstance?has_content>
		<@com.text referenceSubstance.GeneralInfo.ReferenceSubstanceName/>
	<#else>
		<@com.text substance.ChemicalName/>
  	</#if>  
</#compress>
</#macro>